# pypass

Generador de contraseñas seguras desde la consola o en Python. Permite generar contraseñas con diferentes configuraciones como longitud, inclusión de números y caracteres especiales.

## Uso
Esta lib es facilmente utilizable, en consola simplemente use pypass seguido de argumentos, por ejemplo: pypass 16 --con-especiales.
Dentro de un codigo, ocn la lib importada, utilize print(pypass.gen(16, especiales=False)) 

## Instalación

```bash
pip install pypass
